<?php
/**
 * Customizer
 */


if ( ! function_exists( 'inspiry_initialize_defaults' ) ) :
	/**
	 * Helper function to initialize default values for settings as customizer api do not do so by default.
	 *
	 * @param WP_Customize_Manager $wp_customize
	 * @param $inspiry_settings_ids
	 */
	function inspiry_initialize_defaults( WP_Customize_Manager $wp_customize, $inspiry_settings_ids ) {
		if ( is_array( $inspiry_settings_ids ) && ! empty( $inspiry_settings_ids ) ) {
			foreach ( $inspiry_settings_ids as $setting_id ) {
				$setting = $wp_customize->get_setting( $setting_id );
				if ( $setting ) {
					add_option( $setting->id, $setting->default );
				}
			}
		}
	}
endif;

if ( ! function_exists( 'theme_sanitize_radio_select' ) ) :
	/**
	 * Select sanitation function.
	 *
	 * @param string $input Select input.
	 *
	 * @param string $setting Setting name from customizer.
	 *
	 * @return string Return the value after sanitize.
	 */
	function theme_sanitize_radio_select( $input, $setting ) {

		// Input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only.
		$input = sanitize_key( $input );

		// Get the list of possible select options.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// Return input if valid or return default option.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

	}
endif;

require_once INSPIRY_FRAMEWORK . 'customizer/custom/repeater/inc/customizer-repeater.php';
require_once INSPIRY_FRAMEWORK . 'customizer/custom/multi-checkboxes/multicheckboxes.php';

/**
 * Site Logo and Icon
 */
function inspiry_logo_site_icon( WP_Customize_Manager $wp_customize ) {
	$wp_customize->get_setting( 'custom_logo' )->default = get_option( 'theme_sitelogo' );
	$wp_customize->get_setting( 'site_icon' )->default   = get_option( 'theme_favicon' );
}

add_action( 'customize_register', 'inspiry_logo_site_icon', 20, 1 );
/**
 * Header Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/header.php';

/**
 * Home Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/home.php';


/**
 * Landing Page Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/search.php';


/**
 * Contact Page Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/contact.php';


/**
 * Misc Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/social-nav.php';


/**
 * Footer Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/footer.php';


/**
 * Styles Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/styles.php';


/**
 * Typography Settings
 */
require_once INSPIRY_FRAMEWORK . 'customizer/typography.php';