<?php
/**
 * Customizer settings for Search Page
 */

if ( ! function_exists( 'inspiry_search_page_customizer' ) ) :
	function inspiry_search_page_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Search Page Section
		 */
		$wp_customize->add_section( 'inspiry_search_page_section', array(
			'title'    => __( 'Search Area', 'framework' ),
			'priority' => 123,
		) );

		$wp_customize->add_setting( 'theme_search_banner_image', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'theme_search_banner_image', array(
			'label'       => __( 'Search Area Banner Background', 'framework' ),
			'description' => __( 'default banner will be shown if no image selected.', 'framework' ),
			'section'     => 'inspiry_search_page_section',
		) ) );

		/* Search Area Title */
		$wp_customize->add_setting( 'theme_search_title', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'theme_search_title', array(
			'label'       => __( 'Search Area Title', 'framework' ),
			'description' => __( 'Provide the search area title text here.', 'framework' ),
			'type'        => 'text',
			'section'     => 'inspiry_search_page_section',
		) );

		/* Text Below Title */
		$wp_customize->add_setting( 'theme_search_text', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'theme_search_text', array(
			'label'       => __( 'Text Below Title', 'framework' ),
			'description' => __( 'This text will appear below search area main title.', 'framework' ),
			'type'        => 'textarea',
			'section'     => 'inspiry_search_page_section',
		) );
	}

	add_action( 'customize_register', 'inspiry_search_page_customizer' );
endif;


if ( ! function_exists( 'inspiry_search_page_defaults' ) ) :
	/**
	 * Set default values for search_page settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_search_page_defaults( WP_Customize_Manager $wp_customize ) {
		$search_page_settings_ids = array(
			'theme_search_title',
			'theme_search_text',
		);
		inspiry_initialize_defaults( $wp_customize, $search_page_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_search_page_defaults' );
endif;
