<?php
/**
 * Styles Settings
 */


if ( ! function_exists( 'inspiry_styles_customizer' ) ) :
	function inspiry_styles_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Styles Section
		 */

		$wp_customize->add_section( 'inspiry_styles_section', array(
			'title'    => esc_html__( 'Styling', 'framework' ),
			'priority' => 128,
		) );

		/* Theme Stylesheets */
		$wp_customize->add_setting( 'theme_skin', array(
			'type'              => 'option',
			'sanitize_callback' => 'theme_sanitize_radio_select',
		) );
		$wp_customize->add_control( 'theme_skin', array(
			'label'   => esc_html__( 'Color Skin', 'framework' ),
			'section' => 'inspiry_styles_section',
			'type'    => 'radio',
			'choices' => array(
				'default'    => 'Default Skin',
				'blue-skin'  => 'Blue Skin',
				'green-skin' => 'Green Skin',
				'red-skin'   => 'Red Skin',
			),
		) );

		/* Body Text Color */
		$wp_customize->add_setting( 'theme_body_text_color', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_body_text_color', array(
			'label'   => esc_html__( 'Body Text Color', 'framework' ),
			'desc'    => esc_html__( 'Choose a Body Text Color. Base Theme Color is #6f7579', 'framework' ),
			'section' => 'inspiry_styles_section',
		) ) );

		/* Headings Color */
		$wp_customize->add_setting( 'theme_body_headings_color', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_body_headings_color', array(
			'label'   => esc_html__( 'Headings Color', 'framework' ),
			'desc'    => esc_html__( 'Choose a Color for h1, h2, h3, h4, h5 and h6 tags. Base Theme Color is #3b4348', 'framework' ),
			'section' => 'inspiry_styles_section',
		) ) );

		/* Link Color */
		$wp_customize->add_setting( 'theme_link_color', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_link_color', array(
			'label'   => esc_html__( 'Link Color', 'framework' ),
			'desc'    => esc_html__( 'Choose a Link Color. Base Theme Color is #3b4348', 'framework' ),
			'section' => 'inspiry_styles_section',
		) ) );

		/* Link Hover Color */
		$wp_customize->add_setting( 'theme_link_hover_color', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_link_hover_color', array(
			'label'   => esc_html__( 'Link Hover Color', 'framework' ),
			'desc'    => esc_html__( 'Choose a Link Hover Color. Base Theme Color is #395996', 'framework' ),
			'section' => 'inspiry_styles_section',
		) ) );

	}

	add_action( 'customize_register', 'inspiry_styles_customizer' );
endif;


if ( ! function_exists( 'inspiry_styles_defaults' ) ) :
	/**
	 * Set default values for styles settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_styles_defaults( WP_Customize_Manager $wp_customize ) {
		$styles_settings_ids = array(
			'inspiry_theme_stylesheets',
			'theme_quick_css',
		);
		inspiry_initialize_defaults( $wp_customize, $styles_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_styles_defaults' );
endif;
