<?php
/**
 * Functions file to keep all theme functions.
 *
 * @package Knowlegdebase
 */

// Framework Path.
define( 'INSPIRY_FRAMEWORK', get_theme_file_path( '/framework/' ) );

// Set up theme default.
if ( ! function_exists( 'inspiry_theme_setup' ) ) :
	/**
	 * After theme setup.
	 */
	function inspiry_theme_setup() {

		// Load Text Domain.
		load_theme_textdomain( 'framework' );

		/**
		 * Add Automatic Feed Links Support
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Custom Logo
		 */
		add_theme_support( 'custom-logo' );

		/**
		 * Add Post Format Support for Image and Video
		 */
		add_theme_support( 'post-formats', array( 'image', 'video' ) );


		/**
		 * Add Theme Support for Title Tag
		 */
		add_theme_support( 'title-tag' );


		add_theme_support( 'post-thumbnails' );

		// For Post and Pages.
		add_image_size( 'std-thumbnail', 770, 9999 ); // For Standard Post Thumbnails.

		/**
		 * Creating Menu Places
		 */
		register_nav_menus(
			array(
				'main-menu' => 'Top Menu',
			)
		);

	}

	add_action( 'after_setup_theme', 'inspiry_theme_setup' );
endif;

/**
 * Custom Site Icon
 */

if ( ! function_exists( 'inspiry_site_icon' ) ) :
	/**
	 * Theme's Default Site Icon
	 */
	function inspiry_site_icon() {
		if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) :
			$favicon = get_option( 'theme_favicon' );
			if ( ! empty( $favicon ) ) :

				?>
                <link rel="shortcut icon" href="<?php echo esc_url( $favicon ); ?>"/>
			<?php

			endif;
		endif;
	}

	add_action( 'wp_head', 'inspiry_site_icon' );

endif;

/**
 * Google Fonts
 */
require_once INSPIRY_FRAMEWORK . 'google-fonts/google-fonts.php';
/**
 * Theme Enqueue Styles
 */

if ( ! function_exists( 'inspiry_google_fonts' ) ) :
	/**
	 * Google fonts enqueue uri
	 */
	function inspiry_google_fonts() {

		$fonts_url     = '';
		$font_families = array();

		$open_sans              = _x( 'on', 'Open Sans Round font: on or off', '' );
		$droid_serif            = _x( 'on', 'Droid Serif Round font: on or off', '' );
		$inspiry_primary_font   = get_option( 'theme_primary_font' );
		$inspiry_secondary_font = get_option( 'theme_secondary_font' );
		if ( 'Theme Default Font' !== $inspiry_primary_font ) {
			$selected_primary_font = _x( 'on', 'Primary Font: on or off', 'framework' );
			if ( 'off' !== $selected_primary_font ) {
				$font_families[] = $inspiry_primary_font;
			}
		} else {
			if ( 'off' !== $open_sans ) {
				$font_families[] = 'Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800';
			}
		}

		if ( 'Theme Default Font' !== $inspiry_secondary_font ) {
			$selected_secondary_font = _x( 'on', 'Primary Font: on or off', 'framework' );
			if ( 'off' !== $selected_secondary_font ) {
				$font_families[] = $inspiry_secondary_font;
			}
		} else {
			if ( 'off' !== $droid_serif ) {
				$font_families[] = 'Droid+Serif:400,700,400italic,700italic';
			}
		}

		if ( $font_families ) {
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}


endif;

if ( ! function_exists( 'inspiry_enqueue_styles' ) ) :


	/**
	 * Enqueue required styles for front end.
	 */
	function inspiry_enqueue_styles() {
		if ( ! is_admin() ) :
			$inspiry_styles_directory_uri = get_theme_file_uri( '/css/' );

			wp_enqueue_style(
				'google-fonts',
				inspiry_google_fonts(),
				array(),
				''
			);

			wp_enqueue_style(
				'font-awesome',
				$inspiry_styles_directory_uri . 'font-awesome/css/font-awesome.min.css',
				array(),
				''
			);

			wp_enqueue_style(
				'bootstrap',
				$inspiry_styles_directory_uri . 'bootstrap.css',
				array(),
				''
			);

			wp_enqueue_style(
				'main-stylesheet',
				$inspiry_styles_directory_uri . 'main.css',
				array(),
				''
			);

			wp_enqueue_style(
				'responsive-stylesheet',
				$inspiry_styles_directory_uri . 'responsive.css',
				array(),
				''
			);

			wp_enqueue_style(
				'pretty-photo',
				get_theme_file_uri( '/js/prettyphoto/css/prettyPhoto.css' ),
				array(),
				''
			);

			wp_enqueue_style(
				'inspiry-parent-default',
				get_stylesheet_uri(),
				array(),
				''
			);

			wp_enqueue_style(
				'custom-css',
				$inspiry_styles_directory_uri . 'custom.css',
				array(),
				''
			);


			/* Theme Skins */
			$theme_skin = get_option( 'theme_skin' );

			if ( isset( $_GET['skin'] ) ) {
				$theme_skin = $_GET['skin'];
			} elseif ( isset( $_COOKIE['theme_skin'] ) ) {
				$theme_skin = $_COOKIE['theme_skin'];
			}

			if ( ! empty( $theme_skin ) ) {
				switch ( $theme_skin ) {

					case 'blue-skin':
						wp_enqueue_style(
							'blue-skin',
							$inspiry_styles_directory_uri . 'blue-skin.css',
							array(),
							''
						);

						break;
					case 'green-skin':
						wp_enqueue_style(
							'green-skin',
							$inspiry_styles_directory_uri . 'green-skin.css',
							array(),
							''
						);
						break;
					case 'red-skin':
						wp_enqueue_style(
							'red-skin.css',
							$inspiry_styles_directory_uri . 'red-skin.css',
							array(),
							''
						);

						break;
				}
			}


		endif;

	}
endif;

add_action( 'wp_enqueue_scripts', 'inspiry_enqueue_styles' );

if ( ! function_exists( 'inspiry_enqueue_scripts' ) ) :
	/**
	 * Theme Enqueue Scripts
	 */
	function inspiry_enqueue_scripts() {
		if ( ! is_admin() ) :

			$inspiry_scripts_directory_uri = get_theme_file_uri( '/js/' );

			wp_enqueue_script( 'jquery' );

			wp_enqueue_script(
				'prettyphoto',
				$inspiry_scripts_directory_uri . 'prettyphoto/jquery.prettyPhoto.js',
				array( 'jquery' ),
				'',
				true
			);

			wp_enqueue_script(
				'jquery-easing',
				$inspiry_scripts_directory_uri . 'jquery.easing.1.3.js',
				array( 'jquery' ),
				'',
				true
			);

			wp_enqueue_script(
				'jquery-validation',
				$inspiry_scripts_directory_uri . 'jquery.validate.min.js',
				array( 'jquery' ),
				'',
				true
			);

			wp_enqueue_script(
				'jquery-form',
				$inspiry_scripts_directory_uri . 'jquery.form.js',
				array( 'jquery' ),
				'',
				true
			);

			wp_enqueue_script(
				'liveSearch',
				$inspiry_scripts_directory_uri . 'jquery.liveSearch.js',
				array( 'jquery' ),
				'',
				true
			);

			wp_enqueue_script(
				'custom',
				$inspiry_scripts_directory_uri . 'custom.js',
				array( 'jquery' ),
				'',
				true
			);

			// comment reply.
			if ( is_singular() ) {
				wp_enqueue_script( 'comment-reply' );
			}

			$localized_array = array(
				'nav_title' => esc_html__( 'Go to...', 'framework' ),
				'home_url'  => home_url( '/' ),
			);
			wp_localize_script( 'custom', 'localized', $localized_array );

			wp_enqueue_script( 'custom' );

		endif;
	}
endif;

add_action( 'wp_enqueue_scripts', 'inspiry_enqueue_scripts' );

if ( ! function_exists( 'inspiry_admin_scripts' ) ) :
	/**
	 * Enqueue Admin Scripts.
	 *
	 * @param string $hook admin hook for js.
	 */
	function admin_js( $hook ) {
		if ( 'post.php' === $hook || 'post-new.php' === $hook ) {
			wp_enqueue_script(
				'admin',
				get_theme_file_uri( '/js/admin.js' ),
				array( 'jquery' ),
				'',
				true
			);
		}
	}

	add_action( 'admin_enqueue_scripts', 'admin_js' );
endif;

/**
 * Add HTML5 Shim
 */

function add_ie_html5_shim() {
	echo '<!--[if lt IE 9]>';
	echo '<script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>';
	echo '<![endif]-->';
}

add_action( 'wp_head', 'add_ie_html5_shim' );


if ( ! function_exists( 'inspiry_quick_js' ) ) :

	/**
	 * Quick JS for Google Analytics.
	 */
	function inspiry_quick_js() {

		$google_analytics = get_option( 'theme_google_analytics' );

		if ( ! empty( $google_analytics ) ) :
			echo stripslashes( $google_analytics );
		endif;

	}

	add_action( 'wp_head', 'inspiry_quick_js' );
endif;


/**
 * TGM Plugin Activation Class and related code to get the plugins installed and activated.
 */
require_once get_theme_file_path( '/tgm/plugins-list.php' );

/**
 * Inline Styles
 */
require_once get_theme_file_path( '/admin/dynamic-inline-styles.php' );


/**
 * Include Theme Options Framework
 */
require_once get_theme_file_path( '/admin/admin-functions.php' );
require_once get_theme_file_path( '/admin/admin-interface.php' );
require_once get_theme_file_path( '/admin/theme-settings.php' );


/**
 * Include Theme Functions for Various Important Features
 */
require_once get_theme_file_path( '/functions/contact_form_handler.php' );

require_once get_theme_file_path( '/functions/theme_comment.php' );


if ( ! function_exists( '_wp_render_title_tag' ) ) :
	function inspiry_render_title() {
		?>
        <title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}

	add_action( 'wp_head', 'inspiry_render_title' );
endif;


/**
 * Include Custom Post Type For Services
 */
require_once get_theme_file_path( '/include/meta-boxes.php' );


/**
 * Include Custom Post Type For Services
 */
require_once get_theme_file_path( '/include/faq-post-type.php' );


/**
 *Widgets
 */
require_once get_theme_file_path( '/widgets/flickr-widget.php' );
require_once get_theme_file_path( '/widgets/support-widget.php' );
require_once get_theme_file_path( '/widgets/quick-links-widget.php' );
require_once get_theme_file_path( '/widgets/latest-articles-widget.php' );
require_once get_theme_file_path( '/widgets/featured-articles-widget.php' );
require_once get_theme_file_path( '/widgets/google-search.php' );


/**
 * Register Widgets
 */
function register_theme_widgets() {
	register_widget( 'Flickr_Widget' );
	register_widget( 'Support_Widget' );
	register_widget( 'Quick_Links_Widget' );
	register_widget( 'Latest_Articles_Widget' );
	register_widget( 'Featured_Articles_Widget' );
}

add_action( 'widgets_init', 'register_theme_widgets' );


/**
 * Shortcodes
 */
require_once get_theme_file_path( '/include/shortcodes/columns.php' );
require_once get_theme_file_path( '/include/shortcodes/elements.php' );


/**
 * Dynamic CSS
 */
require_once get_theme_file_path( '/css/dynamic-css.php' );


/**
 * Customizer
 */
require_once INSPIRY_FRAMEWORK . 'customizer/customizer.php';


/**
 * Once Click Demo Install
 */
require_once INSPIRY_FRAMEWORK . 'demo/demo.php';


if ( ! function_exists( 'inspiry_settings_after_content_import' ) ) {

	/**
	 * Set Home as front page and Blog as Posts Page after demo contents import
	 */
	function inspiry_settings_after_content_import() {

		// set homepage as front page and blog page as posts page.
		$home_page = get_page_by_title( 'Home' );
		$blog_page = get_page_by_title( 'Articles List' );

		if ( $home_page || $blog_page ) {
			update_option( 'show_on_front', 'page' );
		}

		if ( $home_page ) {
			update_option( 'page_on_front', $home_page->ID );
		}

		if ( $blog_page ) {
			update_option( 'page_for_posts', $blog_page->ID );
		}

	}
}
add_action( 'radium_importer_after_content_import', 'inspiry_settings_after_content_import' );


if ( ! function_exists( 'inspiry_register_sidebar' ) ) {

	/**
	 * Enables Wigitized Sidebars
	 */
	function inspiry_register_sidebar() {
		// Location: Default Sidebar.
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'framework' ),
			'id'            => 'default-sidebar',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Home Sidebar.
		register_sidebar( array(
			'name'          => esc_html__( 'Home Sidebar', 'framework' ),
			'id'            => 'home-sidebar',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Page Sidebar.
		register_sidebar( array(
			'name'          => esc_html__( 'Pages Sidebar', 'framework' ),
			'id'            => 'page-sidebar',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Contact Sidebar.
		register_sidebar( array(
			'name'          => esc_html__( 'Contact Sidebar', 'framework' ),
			'id'            => 'contact-sidebar',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Footer First Column.
		register_sidebar( array(
			'name'          => esc_html__( 'Footer First Column', 'framework' ),
			'id'            => 'footer-first-column',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Footer Second Column.
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Second Column', 'framework' ),
			'id'            => 'footer-second-column',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Footer Third Column.
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Third Column', 'framework' ),
			'id'            => 'footer-third-column',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );

		// Location: Footer Fourth Column.
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Fourth Column', 'framework' ),
			'id'            => 'footer-fourth-column',
			'before_widget' => '<section class="widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="title">',
			'after_title'   => '</h3>',
		) );
	}

	add_action( 'widgets_init', 'inspiry_register_sidebar' );
}


/**
 * Custom Excerpt Method
 */
function framework_excerpt( $len = 15, $trim = '&hellip;' ) {
	$limit     = $len + 1;
	$excerpt   = explode( ' ', get_the_excerpt(), $limit );
	$num_words = count( $excerpt );
	if ( $num_words >= $len ) {
		$last_item = array_pop( $excerpt );
	} else {
		$trim = '';
	}
	$excerpt = implode( ' ', $excerpt ) . "$trim";
	echo $excerpt;
}

function get_framework_excerpt( $len = 15, $trim = '&hellip;' ) {
	$limit     = $len + 1;
	$excerpt   = explode( ' ', get_the_excerpt(), $limit );
	$num_words = count( $excerpt );
	if ( $num_words >= $len ) {
		$last_item = array_pop( $excerpt );
	} else {
		$trim = '';
	}
	$excerpt = implode( ' ', $excerpt ) . "$trim";

	return $excerpt;
}


/**
 * Content Width
 */
if ( ! isset( $content_width ) ) {
	$content_width = 770;
}


/**
 * Editor Styles
 */
function inspiry_theme_editor_styles() {
	add_editor_style( '/css/custom-editor-style.css' );
}

add_action( 'admin_init', 'inspiry_theme_editor_styles' );

/**
 * Theme Pagination Method
 */

function theme_pagination( $pages = '' ) {
	global $paged;
	$paged = get_query_var( 'paged' );

	if ( empty( $paged ) ) {
		$paged = 1;
	}

	$prev      = $paged - 1;
	$next      = $paged + 1;
	$range     = 2; // only change it to show more links.
	$showitems = ( $range * 2 ) + 1;

	if ( '' === $pages ) {
		global $wp_query;
		$pages = $wp_query->max_num_pages;
		if ( ! $pages ) {
			$pages = 1;
		}
	}


	if ( 1 !== $pages ) {
		echo "<div id='pagination'>";
		echo ( $paged > 2 && $paged > $range + 1 && $showitems < $pages ) ? "<a href='" . get_pagenum_link( 1 ) . "' class='btn'>&laquo; " . esc_html__( 'First', 'framework' ) . '</a> ' : '';
		echo ( $paged > 1 && $showitems < $pages ) ? "<a href='" . get_pagenum_link( $prev ) . "' class='btn' >&laquo; " . esc_html__( 'Previous', 'framework' ) . '</a> ' : '';


		for ( $i = 1; $i <= $pages; $i ++ ) {
			if ( 1 !== $pages && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged === $i ) ? "<a href='" . get_pagenum_link( $i ) . "' class='btn active' >" . $i . '</a> ' : "<a href='" . get_pagenum_link( $i ) . "' class='btn'>" . $i . '</a> ';
			}
		}

		echo ( $paged < $pages && $showitems < $pages ) ? "<a href='" . get_pagenum_link( $next ) . "' class='btn' >" . esc_html__( 'Next', 'framework' ) . ' &raquo;</a> ' : '';
		echo ( $paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages ) ? "<a href='" . get_pagenum_link( $pages ) . "' class='btn' >" . esc_html__( 'Last', 'framework' ) . ' &raquo;</a> ' : '';
		echo '</div>';
	}
}


/**
 * Theme Breadcrumb
 */
function theme_breadcrumb() {

	echo '<ul class="breadcrumb">';

	if ( ! is_front_page() ) {
		echo '<li>';
		echo '<a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html( get_bloginfo( 'name' ) ) . '</a>';
		echo '<span class="divider">/</span></li>';
	}

	if ( is_category() || is_singular( 'post' ) ) {
		$category = get_the_category();
		$id       = $category[0]->cat_ID;
		echo '<li>';
		echo wp_kses_post( get_category_parents( $id, true, ' <span class="divider">/</span></li><li>', false ) );
	}

	if ( is_singular( 'post' ) || is_page() ) {
		echo '<li class="active">';
		the_title();
		echo '</li>';
	}

	if ( is_tag() ) {
		echo '<li>';
		esc_html_e( 'Tag: ', 'framework' );
		echo single_tag_title( '', false );
		echo '</li>';
	}

	if ( is_404() ) {
		echo '<li>';
		esc_html_e( '404 - Page not Found', 'framework' );
		echo '</li>';

	}

	if ( is_search() ) {
		echo '<li>';
		esc_html_e( 'Search', 'framework' );
		echo '</li>';
	}

	if ( is_year() ) {
		echo '</li>';
		echo esc_html( get_the_time( 'Y' ) );
		echo '</li>';
	}

	echo '</ul>';

}


/**
 * Like Button AJAX request Handler
 */

add_action( 'wp_ajax_nopriv_like_it', 'like_it' );
add_action( 'wp_ajax_like_it', 'like_it' );

function like_it() {

	if ( isset( $_POST['post_id'] ) ) {

		$ip      = $_SERVER['REMOTE_ADDR'];
		$post_id = intval( $_POST['post_id'] );

		$voted_ip = get_post_meta( $post_id, 'voted_IP', true );

		if ( ! is_array( $voted_ip ) ) {
			$voted_ip = array();
		}

		if ( ! in_array( $ip, $voted_ip, true ) ) {

			$existing_likes = get_post_meta( $post_id, 'likes_count', true );
			if ( empty( $existing_likes ) ) {
				$existing_likes = 1;
			} else {
				$existing_likes = intval( $existing_likes ) + 1;
			}

			if ( update_post_meta( $post_id, 'likes_count', $existing_likes ) ) {
				$voted_ip[] = $ip;
				update_post_meta( $post_id, 'voted_IP', $voted_ip );
				echo wp_kses_post( $existing_likes );
			} else {
				esc_html_e( 'Action failed due to some server issue!', 'framework' );
			}
		} else {
			esc_html_e( 'Already Liked!', 'framework' );
		}
	} else {
		esc_html_e( 'Invalid Parameters!', 'framework' );
	}
	die;
}


/**
 * Already Liked or Not
 */
function already_liked( $post_id ) {
	$ip       = $_SERVER['REMOTE_ADDR'];
	$voted_ip = get_post_meta( intval( $post_id ), 'voted_IP', true );

	if ( ! empty( $voted_ip ) && is_array( $voted_ip ) ) {
		return in_array( $ip, $voted_ip );
	}

	return false;
}


/**
 * Get Total Likes
 *
 * @param int $post_id Post id will be passed.
 *
 * @return integer It will return likes.
 */
function get_total_likes( $post_id ) {
	$existing_likes = get_post_meta( $post_id, 'likes_count', true );

	if ( empty( $existing_likes ) ) {
		$existing_likes = 0;
	} else {
		$existing_likes = intval( $existing_likes );
	}

	return $existing_likes;
}


/**
 * Redirect User to Theme Options Page after Theme Activation
 */
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && 'themes.php' === $pagenow ) {
	wp_safe_redirect( admin_url( 'admin.php?page=siteoptions' ) );
	exit;
}


/**
 * Remove rel attribute from the category list
 *
 * @param string $output Template Tags.
 *
 * @return string It will return html tags list.
 */
function remove_category_list_rel( $output ) {
	$output = str_replace( ' rel="tag"', '', $output );
	$output = str_replace( ' rel="category"', '', $output );
	$output = str_replace( ' rel="category tag"', '', $output );

	return $output;
}

add_filter( 'wp_list_categories', 'remove_category_list_rel' );
add_filter( 'the_category', 'remove_category_list_rel' );


/**
 * Custom Excerpt Length
 *
 * @param integer $length Letters count parameter.
 *
 * @return integer Letters count.
 */
function custom_excerpt_length( $length ) {
	return 50;
}

add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );


/**
 * Read More Link
 *
 * @param string $more filter excerpt_more.
 *
 * @return string Html more tag will be returned.
 */
function new_excerpt_more( $more ) {
	global $post;

	return ' . . . <a class="readmore-link" href="' . get_permalink( $post->ID ) . '">' . esc_html__( 'Read more', 'framework' ) . '</a>';
}

add_filter( 'excerpt_more', 'new_excerpt_more' );


/**
 * Read More Link
 *
 * @param array $query_arg Query arg will be passed to the functions.
 */
function list_articles( $query_arg ) {

	$articles_list = new WP_Query( $query_arg );

	if ( $articles_list->have_posts() ) :
		echo '<ul class="articles">';
		while ( $articles_list->have_posts() ) :
			$articles_list->the_post();
			get_template_part( 'template-parts/article-for-widget' );
		endwhile;
		echo '</ul>';
	else :
		?>
        <p><?php esc_html_e( 'No Articles Found!', 'framework' ); ?></p>
	<?php
	endif;
}

/**
 * Skin Related Code For Demo
 */
if ( isset( $_GET['skin'] ) ) {
	$theme_skin = $_GET['skin'];
	setcookie( 'theme_skin', $theme_skin, time() + 600 );
}


add_filter( 'bbp_register_forum_post_type', 'bbp_register_search' );
add_filter( 'bbp_register_topic_post_type', 'bbp_register_search' );
add_filter( 'bbp_register_reply_post_type', 'bbp_register_search' );
/**
 * Include bbPress in Search Results
 *
 * @param string $post_type will be passed.
 *
 * @return string
 */
function bbp_register_search( $post_type ) {
	$post_type['exclude_from_search'] = false;

	return $post_type;
}


/**
 * Display icon based on post format
 *
 * @param string $format Post format passed.
 */
function inspiry_post_format_icon( $format ) {
	switch ( $format ) {
		case 'image':
		case 'gallery':
			echo '<i class="fa fa-picture-o"></i>';
			break;

		case 'video':
			echo '<i class="fa fa-film"></i>';
			break;

		case 'faq':
			echo '<i class="fa fa-question-circle"></i>';
			break;

		case 'reply':
			echo '<i class="fa fa-comment"></i>';
			break;

		case 'topic':
			echo '<i class="fa fa-comment-o"></i>';
			break;

		case 'forum':
			echo '<i class="fa fa-th-list"></i>';
			break;

		default:
			echo '<i class="fa fa-pencil-square-o"></i>';
			break;
	}
}
