<?php
/**
 * Customizer settings for Home
 *
 * @package PP
 */

if ( ! function_exists( 'inspiry_home_customizer' ) ) :

	/**
	 * Homepage settings function.
	 *
	 * @param WP_Customize_Manager $wp_customize All data is here.
	 */
	function inspiry_home_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Home Panel
		 */

		// Access the WordPress Categories via an Array.
		$theme_categories     = [];
		$theme_categories_obj = get_categories( 'hide_empty=0' );
		foreach ( $theme_categories_obj as $theme_cat ) {
			$theme_categories[ $theme_cat->term_id ] = $theme_cat->name . " ($theme_cat->count)";
		}

		// Access the WordPress Tags via an Array.
		$theme_tags     = array( ' ' => __( 'Select a Tag:', 'framework' ) );
		$theme_tags_obj = get_tags( 'hide_empty=0' );
		foreach ( $theme_tags_obj as $theme_tag ) {
			$theme_tags[ $theme_tag->slug ] = $theme_tag->name;
		}

		$theme_options_numbers = array(
			1  => 1,
			2  => 2,
			3  => 3,
			4  => 4,
			5  => 5,
			6  => 6,
			7  => 7,
			8  => 8,
			9  => 9,
			10 => 10,
		);

		/* Home Panel */
		$wp_customize->add_section( 'inspiry_home_section', array(
			'title'    => __( 'Home Page', 'framework' ),
			'priority' => 122,
		) );

		/* Featured Articles Title */
		$wp_customize->add_setting( 'theme_featured_articles_title', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'theme_featured_articles_title', array(
			'label'   => __( 'Featured Articles Title', 'framework' ),
			'type'    => 'text',
			'section' => 'inspiry_home_section',
		) );

		/* Choose a tag for homepage featured articles */
		$wp_customize->add_setting( 'theme_feature_tag', array(
			'type'              => 'option',
			'sanitize_callback' => 'theme_sanitize_radio_select',
		) );
		$wp_customize->add_control( 'theme_feature_tag', array(
			'label'       => __( 'Choose a tag for homepage featured articles.', 'framework' ),
			'description' => __( 'Homepage featured articles sections will display articles based on selected tag.', 'framework' ),
			'type'        => 'select',
			'section'     => 'inspiry_home_section',
			'choices'     => $theme_tags,
		) );


		/* Latest Articles Title */
		$wp_customize->add_setting( 'theme_latest_articles_title', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'theme_latest_articles_title', array(
			'label'   => __( 'Latest Articles Title', 'framework' ),
			'type'    => 'text',
			'section' => 'inspiry_home_section',
		) );

		/* Choose a tag for homepage featured articles */
		$wp_customize->add_setting( 'theme_number_of_articles', array(
			'type'              => 'option',
			'sanitize_callback' => 'theme_sanitize_radio_select',
		) );
		$wp_customize->add_control( 'theme_number_of_articles', array(
			'label'       => __( 'Number of articles to display.', 'framework' ),
			'description' => __( 'Number of articles to display for latest and featured section on homepage.', 'framework' ),
			'type'        => 'select',
			'section'     => 'inspiry_home_section',
			'choices'     => $theme_options_numbers,
		) );

		$wp_customize->add_setting( 'theme_selected_cats', array(
			'type'              => 'option',
			'sanitize_callback' => 'inspiry_sanitize_muti_checkbox',
		) );

		$wp_customize->add_control( new Inspiry_Customize_Control_Checkbox_Multiple( $wp_customize, 'theme_selected_cats', array(
			'section' => 'inspiry_home_section',
			'label'   => __( 'Select Categories', 'framework' ),
			'choices' => $theme_categories,
		) ) );

		/* Number of articles to display for each category */
		$wp_customize->add_setting( 'theme_number_articles_for_cat', array(
			'type'              => 'option',
			'sanitize_callback' => 'theme_sanitize_radio_select',
		) );
		$wp_customize->add_control( 'theme_number_articles_for_cat', array(
			'label'       => __( 'Number of articles to display for each category', 'framework' ),
			'description' => __( 'Number of articles to display for each category on Homepage Template with Category and Article List.', 'framework' ),
			'type'        => 'select',
			'section'     => 'inspiry_home_section',
			'choices'     => $theme_options_numbers,
		) );
	}

	add_action( 'customize_register', 'inspiry_home_customizer' );
endif;


if ( ! function_exists( 'inspiry_home_defaults' ) ) :
	/**
	 * Set default values for Homepage settings
	 *
	 * @param WP_Customize_Manager $wp_customize All data is here.
	 */
	function inspiry_home_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'theme_featured_articles_title',
			'theme_feature_tag',
			'theme_latest_articles_title',
			'theme_latest_articles_title',
			'theme_number_articles_for_cat',

		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_home_defaults' );
endif;
