<?php
/**
 * File Name: quick-links-widget.php
 */

class Quick_Links_Widget extends WP_Widget {

	function __construct() {
		$widget_ops = array( 'description' => __( 'Use this widget to add one of your custom menus as Quick Links widget in Knowledge Base Theme.', 'framework' ) );
		parent::__construct( 'quick_link_widget', __( 'Knowledge Base - Quick Links Widget', 'framework' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		// Get menu
		$nav_menu = ! empty( $instance['nav_menu'] ) ? wp_get_nav_menu_object( $instance['nav_menu'] ) : false;

		if ( ! $nav_menu ) {
			return;
		}

		$instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		echo $args['before_widget'];

		echo '<div class="quick-links-widget">';

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . $instance['title'] . $args['after_title'];
		}

		wp_nav_menu( array(
			'fallback_cb' => '',
			'menu'        => $nav_menu,
			'container'   => false,
			'menu_class'  => 'menu clearfix',
		) );

		echo '</div>';

		echo $args['after_widget'];
	}

	function update( $new_instance, $old_instance ) {
		$instance['title']    = strip_tags( stripslashes( $new_instance['title'] ) );
		$instance['nav_menu'] = (int) $new_instance['nav_menu'];

		return $instance;
	}

	function form( $instance ) {
		$title    = isset( $instance['title'] ) ? $instance['title'] : __( 'Quick Links', 'framework' );
		$nav_menu = isset( $instance['nav_menu'] ) ? $instance['nav_menu'] : '';

		// Get menus.
		$menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

		// If no menus exists, direct the user to go and create some.
		if ( ! $menus ) {
			echo '<p>' . sprintf( esc_html__( 'No menus have been created yet. <a href="%s">Create some</a>.', 'framework' ), esc_url( admin_url( 'nav-menus.php' ) ) ) . '</p>';

			return;
		}
		?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'framework' ) ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_html( $title ); ?>"/>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'nav_menu' ); ?>"><?php _e( 'Select Menu:', 'framework' ); ?></label>
            <select id="<?php echo $this->get_field_id( 'nav_menu' ); ?>" name="<?php echo $this->get_field_name( 'nav_menu' ); ?>">
				<?php
				foreach ( $menus as $menu ) {
					echo '<option value="' . esc_attr( $menu->term_id ) . '"' . selected( $nav_menu, $menu->term_id, false ) . '>' . $menu->name . '</option>';
				}
				?>
            </select>
        </p>
		<?php
	}
}
